<?php
/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\REPEATER;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Content_Slider_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_content_slider';
    }

    public function get_title() {
        return esc_html__('Content Slider', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-post-slider';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    public function get_script_depends() {
        return ['content_slider_widget'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Content Slider', 'cosmecos_plugin')
            ]
        );

        $this->add_responsive_control(
            'slider_height',
            [
                'label'     => esc_html__('Slider Height', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size'      => '973',
                    'unit'      => 'px'
                ],
                'range'     => [
                    'px'        => [
                        'min'       => 10,
                        'max'       => 2000,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .cosmecos_content_slide' => 'height: {{SIZE}}{{UNIT}};'
                ],
                'separator' => 'before'
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'slide_name',
            [
                'label' => esc_html__('Slide Name', 'cosmecos_plugin'),
                'type' => Controls_Manager::TEXT,
                'default' => '',
                'separator' => 'after'
            ]
        );

        $repeater->add_control(
            'slide_type',
            [
                'label' => esc_html__('Slide Type', 'cosmecos_plugin'),
                'type' => Controls_Manager::SELECT,
                'default' => 'fade_in_right',
                'options' => [
                    'fade_in_right' => esc_html__('Fade In Right', 'cosmecos_plugin'),
                    'fade_in_left' => esc_html__('Fade In Left', 'cosmecos_plugin'),
                    'corners_to_center' => esc_html__('Corners To Center', 'cosmecos_plugin')
                ],
                'separator' => 'after'
            ]
        );



        $repeater->start_controls_tabs('button_settings_tabs');

            // -------------------- //
            // ------ BG Tab ------ //
            // -------------------- //
            $repeater->start_controls_tab(
                'tab_bg',
                [
                    'label' => esc_html__('BG', 'cosmecos_plugin')
                ]
            );

                $repeater->add_group_control(
                    Group_Control_Background::get_type(),
                    [
                        'name' => 'background',
                        'label' => esc_html__( 'Background', 'cosmecos_plugin' ),
                        'types' => [ 'classic' ],
                        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}'
                    ]
                );

            $repeater->end_controls_tab();

            // ----------------------- //
            // ------ Image Tab ------ //
            // ----------------------- //
            $repeater->start_controls_tab(
                'tab_image',
                [
                    'label' => esc_html__('Image', 'cosmecos_plugin')
                ]
            );

                $repeater->add_control(
                    'active_image',
                    [
                        'label' => esc_html__('Active Image', 'cosmecos_plugin'),
                        'type' => Controls_Manager::MEDIA,
                        'default' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'condition' => [
                            'slide_type' => ['fade_in_right', 'fade_in_left']
                        ]
                    ]
                );

                $repeater->add_responsive_control(
                    'image_margin',
                    [
                        'label' => esc_html__('Position', 'cosmecos_plugin'),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => ['%', 'px'],
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .active_image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                        'condition' => [
                            'slide_type' => ['fade_in_right', 'fade_in_left']
                        ]
                    ]
                );

                $repeater->add_control(
                    'active_image_1',
                    [
                        'label' => esc_html__('Top Left Corner Image', 'cosmecos_plugin'),
                        'type' => Controls_Manager::MEDIA,
                        'default' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'condition' => [
                            'slide_type' => 'corners_to_center'
                        ]
                    ]
                );

                $repeater->add_control(
                    'active_image_2',
                    [
                        'label' => esc_html__('Top Right Corner Image', 'cosmecos_plugin'),
                        'type' => Controls_Manager::MEDIA,
                        'default' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'condition' => [
                            'slide_type' => 'corners_to_center'
                        ]
                    ]
                );

                $repeater->add_control(
                    'active_image_3',
                    [
                        'label' => esc_html__('Bottom Right Corner Image', 'cosmecos_plugin'),
                        'type' => Controls_Manager::MEDIA,
                        'default' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'condition' => [
                            'slide_type' => 'corners_to_center'
                        ]
                    ]
                );

                $repeater->add_control(
                    'active_image_4',
                    [
                        'label' => esc_html__('Bottom Left Corner Image', 'cosmecos_plugin'),
                        'type' => Controls_Manager::MEDIA,
                        'default' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'condition' => [
                            'slide_type' => 'corners_to_center'
                        ]
                    ]
                );

            $repeater->end_controls_tab();

            // ----------------------- //
            // ------ Title Tab ------ //
            // ----------------------- //
            $repeater->start_controls_tab(
                'tab_title',
                [
                    'label' => esc_html__('Title', 'cosmecos_plugin')
                ]
            );

                $repeater->add_control(
                    'heading',
                    [
                        'label' => esc_html__('Title', 'cosmecos_plugin'),
                        'type' => Controls_Manager::WYSIWYG,
                        'label_block' => true,
                        'placeholder' => esc_html__('Enter Title', 'cosmecos_plugin'),
                        'default' => esc_html__('Title', 'cosmecos_plugin')
                    ]
                );

                $repeater->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                        'name' => 'heading_typography',
                        'label' => esc_html__('Heading Typography', 'cosmecos_plugin'),
                        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slider_title'
                    ]
                );

                $repeater->add_control(
                    'heading_color',
                    [
                        'label' => esc_html__('Heading Color', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slider_title' => 'color: {{VALUE}};'
                        ]
                    ]
                );

            $repeater->end_controls_tab();

            // ---------------------- //
            // ------ Text Tab ------ //
            // ---------------------- //
            $repeater->start_controls_tab(
                'tab_text',
                [
                    'label' => esc_html__('Text', 'cosmecos_plugin')
                ]
            );

                $repeater->add_control(
                    'text',
                    [
                        'label' => esc_html__('Promo Text', 'cosmecos_plugin'),
                        'type' => Controls_Manager::WYSIWYG,
                        'default' => '',
                        'placeholder' => esc_html__('Enter Promo Text', 'cosmecos_plugin'),
                        'separator' => 'before'
                    ]
                );

                $repeater->add_group_control(
                    Group_Control_Typography::get_type(),
                    [
                        'name' => 'text_typography',
                        'label' => esc_html__('Text Typography', 'cosmecos_plugin'),
                        'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slider_promo_text'
                    ]
                );

                $repeater->add_control(
                    'text_color',
                    [
                        'label' => esc_html__('Text Color', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slider_promo_text' => 'color: {{VALUE}};'
                        ]
                    ]
                );

                $repeater->add_responsive_control(
                    'content_margin',
                    [
                        'label' => esc_html__('Content Margin', 'cosmecos_plugin'),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => ['px', '%'],
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_container' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ],
                        'separator' => 'before'
                    ]
                );

                $repeater->add_responsive_control(
                    'text_padding',
                    [
                        'label' => esc_html__('Promo Text Padding', 'cosmecos_plugin'),
                        'type' => Controls_Manager::DIMENSIONS,
                        'size_units' => ['px', '%'],
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slider_promo_text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                        ]
                    ]
                );

            $repeater->end_controls_tab();

            // ------------------------ //
            // ------ Button Tab ------ //
            // ------------------------ //
            $repeater->start_controls_tab(
                'tab_button',
                [
                    'label' => esc_html__('Button', 'cosmecos_plugin')
                ]
            );

                $repeater->add_control(
                    'button_text',
                    [
                        'label' => esc_html__('Button Text', 'cosmecos_plugin'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Button', 'cosmecos_plugin'),
                        'separator' => 'before'
                    ]
                );

                $repeater->add_control(
                    'button_link',
                    [
                        'label' => esc_html__('Button Link', 'cosmecos_plugin'),
                        'type' => Controls_Manager::URL,
                        'label_block' => true,
                        'default' => [
                            'url' => '',
                            'is_external' => 'true',
                        ],
                        'placeholder' => esc_html__( 'http://your-link.com', 'cosmecos_plugin' )
                    ]
                );

                $repeater->add_control(
                    'button_color',
                    [
                        'label' => esc_html__('Button Color', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button' => 'color: {{VALUE}};'
                        ],
                        'separator' => 'before'
                    ]
                );

                $repeater->add_control(
                    'button_bd',
                    [
                        'label' => esc_html__('Button Border', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

                $repeater->add_control(
                    'button_bg',
                    [
                        'label' => esc_html__('Button Background', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button:before' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );

                $repeater->add_control(
                    'button_color_hover',
                    [
                        'label' => esc_html__('Button Hover', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button:hover' => 'color: {{VALUE}};'
                        ],
                        'separator' => 'before'
                    ]
                );

                $repeater->add_control(
                    'button_bd_hover',
                    [
                        'label' => esc_html__('Button Border Hover', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button:hover' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

                $repeater->add_control(
                    'button_bg_hover',
                    [
                        'label' => esc_html__('Button Background Hover', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button:hover:before' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );

                $repeater->add_responsive_control(
                    'button_top_margin',
                    [
                        'label' => esc_html__('Button Top Space', 'cosmecos_plugin'),
                        'type' => Controls_Manager::SLIDER,
                        'range' => [
                            'px' => [
                                'min' => 0,
                                'max' => 200
                            ]
                        ],
                        'selectors' => [
                            '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos-button' => 'margin-top: {{SIZE}}{{UNIT}};'
                        ]
                    ]
                );

            $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $repeater->add_responsive_control(
            'content_max_width',
            [
                'label' => esc_html__('Content Container Max Width', 'cosmecos_plugin'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['%', 'px'],
                'range' => [
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 50,
                        'max' => 2000,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_container' => 'max-width: {{SIZE}}{{UNIT}};'
                ],
                'separator' => 'before'
            ]
        );

        $repeater->add_responsive_control(
            'content_align',
            [
                'label' => esc_html__('Content Container Alignment', 'cosmecos_plugin'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'cosmecos_plugin' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'cosmecos_plugin' ),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'cosmecos_plugin' ),
                        'icon' => 'eicon-h-align-right',
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slide_wrapper' => 'justify-content: {{VALUE}};'
                ],
                'separator' => 'before'
            ]
        );

        $repeater->add_responsive_control(
            'content_v_align',
            [
                'label' => esc_html__('Content Container Vertical Alignment', 'cosmecos_plugin'),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'center',
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'cosmecos_plugin' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'cosmecos_plugin' ),
                        'icon' => 'eicon-v-align-middle',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'cosmecos_plugin' ),
                        'icon' => 'eicon-v-align-bottom',
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_slide_wrapper' => 'align-items: {{VALUE}};'
                ],
                'separator' => 'before'
            ]
        );

        $repeater->add_responsive_control(
            'content_text_align',
            [
                'label' => esc_html__('Content Container Text Align', 'cosmecos_plugin'),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'center',
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'cosmecos_plugin' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'cosmecos_plugin' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'cosmecos_plugin' ),
                        'icon' => 'eicon-text-align-right',
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .cosmecos_content_container' => 'text-align: {{VALUE}};'
                ],
                'separator' => 'before'
            ]
        );

        $repeater->add_control(
            'divider_1',
            [
                'type' => Controls_Manager::DIVIDER,
            ]
        );

        $this->add_control(
            'slides',
            [
                'label' => esc_html__('Slides', 'cosmecos_plugin'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{slide_name}}}',
                'prevent_empty' => false,
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();

        // ---------------------------- //
        // ---------- Slider ---------- //
        // ---------------------------- //
        $this->start_controls_section(
            'section_slider',
            [
                'label' => esc_html__('Slider Settings', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'cosmecos_plugin'),
                'type' => Controls_Manager::NUMBER,
                'default' => 1200,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'cosmecos_plugin'),
                'type' => Controls_Manager::SELECT,
                'default' => 'yes',
                'options' => [
                    'yes' => esc_html__('Yes', 'cosmecos_plugin'),
                    'no' => esc_html__('No', 'cosmecos_plugin'),
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'cosmecos_plugin'),
                'type' => Controls_Manager::SELECT,
                'default' => 'yes',
                'options' => [
                    'yes' => esc_html__('Yes', 'cosmecos_plugin'),
                    'no' => esc_html__('No', 'cosmecos_plugin'),
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'cosmecos_plugin'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'cosmecos_plugin'),
                'type' => Controls_Manager::SELECT,
                'default' => 'yes',
                'options' => [
                    'yes' => esc_html__('Yes', 'cosmecos_plugin'),
                    'no' => esc_html__('No', 'cosmecos_plugin'),
                ],
                'condition' => [
                    'autoplay' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'rtl_support',
            [
                'label' => esc_html__('Rtl Support', 'cosmecos_plugin'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'label_off' => esc_html__('Off', 'cosmecos_plugin'),
                'label_on' => esc_html__('On', 'cosmecos_plugin'),
                'separator' => 'before'
            ]
        );

        $this->end_controls_section();

        // ------------------------------------------- //
        // ---------- Button Style Settings ---------- //
        // ------------------------------------------- //
        $this->start_controls_section(
            'section_button_settings',
            [
                'label' => esc_html__('Content Settings', 'cosmecos_plugin'),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'button_typography',
                'label' => esc_html__('Button Typography', 'cosmecos_plugin'),
                'selector' => '{{WRAPPER}} .cosmecos-button'
            ]
        );

        $this->add_control(
            'button_radius',
            [
                'label' => esc_html__('Border Radius', 'cosmecos_plugin'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );

        $this->add_control(
            'button_padding',
            [
                'label' => esc_html__('Button Padding', 'cosmecos_plugin'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .cosmecos-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );

        $this->end_controls_section();

        // ------------------------------------------- //
        // ---------- Button Style Settings ---------- //
        // ------------------------------------------- //
        $this->start_controls_section(
            'section_slider_settings',
            [
                'label' => esc_html__('Slider Settings', 'cosmecos_plugin'),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->start_controls_tabs('button_settings_tabs');

            // ------------------------ //
            // ------ Normal Tab ------ //
            // ------------------------ //
            $this->start_controls_tab(
                'tab_arrows_normal',
                [
                    'label' => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'nav_color',
                    [
                        'label' => esc_html__('Slider Arrows Color', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .slick-arrow:after' => 'color: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'nav_bg',
                    [
                        'label' => esc_html__('Slider Arrows Background', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .slick-arrow:before' => 'background: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'nav_bd',
                    [
                        'label'     => esc_html__('Slider Arrows Border', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .slick-arrow' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

            // ----------------------- //
            // ------ Hover Tab ------ //
            // ----------------------- //
            $this->start_controls_tab(
                'tab_arrows_hover',
                [
                    'label' => esc_html__('Hover', 'cosmecos_plugin')
                ]
            );

                $this->add_control(
                    'nav_hover',
                    [
                        'label' => esc_html__('Slider Arrows Hover', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .slick-arrow:hover:after' => 'color: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'nav_bg_hover',
                    [
                        'label' => esc_html__('Slider Arrows Hover Background', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .slick-arrow:hover:before' => 'background: {{VALUE}};'
                        ]
                    ]
                );

                $this->add_control(
                    'nav_bd_hover',
                    [
                        'label' => esc_html__('Slider Arrows Hover Border', 'cosmecos_plugin'),
                        'type' => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .slick-arrow:hover' => 'border-color: {{VALUE}};'
                        ]
                    ]
                );

            $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings();

        $slides = $settings['slides'];

        if ($settings['rtl_support'] == 'yes') {
            $rtl = true;
        } else {
            $rtl = false;
        }

        $slider_options = [
            'pauseOnHover'  => ('yes' === $settings['pause_on_hover']),
            'autoplay'      => ('yes' === $settings['autoplay']),
            'infinite'      => ('yes' === $settings['infinite']),
            'speed'         => absint($settings['speed']),
            'rtl'           => $rtl
        ];

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        ?>

        <div class="cosmecos_content_slider_widget">
            <div class="cosmecos_content_slider_wrapper">
                <div class="cosmecos_content_slider cosmecos_slider_slick" data-slider-options="<?php echo esc_attr(wp_json_encode($slider_options)); ?>">
                    <?php
                    foreach ($slides as $slide) {
                        echo '<div class="cosmecos_content_slide elementor-repeater-item-' . esc_attr($slide['_id']) . ' slide-animation-type-' . esc_attr($slide['slide_type']) . '">';
                            if ( $slide['slide_type'] == 'corners_to_center' ) {
                                $image_width_px_1   = wp_get_attachment_image_src($slide['active_image_1']['id'], 'full')[1];
                                $image_width_px_2   = wp_get_attachment_image_src($slide['active_image_2']['id'], 'full')[1];
                                $image_width_px_3   = wp_get_attachment_image_src($slide['active_image_3']['id'], 'full')[1];
                                $image_width_px_4   = wp_get_attachment_image_src($slide['active_image_4']['id'], 'full')[1];
                                $width_1            = ( (int)$image_width_px_1 / 1920 ) * 100;
                                $width_2            = ( (int)$image_width_px_2 / 1920 ) * 100;
                                $width_3            = ( (int)$image_width_px_3 / 1920 ) * 100;
                                $width_4            = ( (int)$image_width_px_4 / 1920 ) * 100;
                                $image_width_perc_1 = round($width_1, 4);
                                $image_width_perc_2 = round($width_2, 4);
                                $image_width_perc_3 = round($width_3, 4);
                                $image_width_perc_4 = round($width_4, 4);
                                echo ( !empty($slide['active_image_1']) ? '<div class="active_image active_image_left_top" style="width: ' . esc_attr($image_width_perc_1) . '%;">' . wp_get_attachment_image( $slide['active_image_1']['id'], 'full' ) . '</div>' : '' );
                                echo ( !empty($slide['active_image_2']) ? '<div class="active_image active_image_right_top" style="width: ' . esc_attr($image_width_perc_2) . '%;">' . wp_get_attachment_image( $slide['active_image_2']['id'], 'full' ) . '</div>' : '' );
                                echo ( !empty($slide['active_image_3']) ? '<div class="active_image active_image_right_bottom" style="width: ' . esc_attr($image_width_perc_3) . '%;">' . wp_get_attachment_image( $slide['active_image_3']['id'], 'full' ) . '</div>' : '' );
                                echo ( !empty($slide['active_image_4']) ? '<div class="active_image active_image_left_bottom" style="width: ' . esc_attr($image_width_perc_4) . '%;">' . wp_get_attachment_image( $slide['active_image_4']['id'], 'full' ) . '</div>' : '' );
                            } else {

                                $image_width_px     = wp_get_attachment_image_src($slide['active_image']['id'], 'full')[1];
                                $width = ( (int)$image_width_px / 1920 ) * 100;
                                $image_width_perc   = round($width, 4);

                                echo ( !empty($slide['active_image']) ? '<div class="active_image" style="width: ' . esc_attr($image_width_perc) . '%;">' . wp_get_attachment_image( $slide['active_image']['id'], 'full' ) . '</div>' : '' );
                            }
                                echo '<div class="container cosmecos_full_cont">';
                                    echo '<div class="row cosmecos_full_cont">';
                                        echo '<div class="col-12 cosmecos_full_cont">';
                                            echo '<div class="cosmecos_content_slide_wrapper">';
                                                echo '<div class="cosmecos_content_container">';

                                                    if ( !empty($slide['heading']) ) {
                                                        echo '<div class="cosmecos_content_wrapper_2">';
                                                            echo '<div class="cosmecos_content_slider_title">';
                                                               echo cosmecos_output_code($slide['heading']);
                                                            echo '</div>';
                                                        echo '</div>';
                                                    }

                                                    if ($slide['text'] !== '') {
                                                        echo '<div class="cosmecos_content_wrapper_3">';
                                                            echo '<div class="cosmecos_content_slider_promo_text">' . cosmecos_output_code($slide['text']) . '</div>';
                                                        echo '</div>';
                                                    }

                                                    if ($slide['button_text'] !== '') {
                                                        if ($slide['button_link']['url'] !== '') {
                                                            $button_url = $slide['button_link']['url'];
                                                        } else {
                                                            $button_url = '#';
                                                        }
                                                        echo '<div class="cosmecos_content_wrapper_4">';
                                                            echo '<a class="cosmecos-button" href="' . esc_url($button_url) . '"' . (($slide['button_link']['is_external'] == true) ? ' target="_blank"' : '') . (($slide['button_link']['nofollow'] == 'on') ? ' rel="nofollow"' : '') . '>';
                                                                echo esc_html($slide['button_text']);
                                                            echo '</a>';
                                                        echo '</div>';
                                                    }
                                                echo '</div>';
                                            echo '</div>';

                                        echo '</div>';
                                    echo '</div>';
                                echo '</div>';

                        echo '</div>';
                    }
                    ?>
                </div>
                <div class="slick-navigation">
                    <div class="slick-prev slick-arrow"><?php esc_html_e('Previous', 'cosmecos_plugin'); ?></div>
                    <div class="slick-next slick-arrow"><?php esc_html_e('Next', 'cosmecos_plugin'); ?></div>
                </div>
            </div>
        </div>
        <?php
    }

    protected function content_template() {}

    public function render_plain_content() {}
}