<?php
/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\REPEATER;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Portfolio_Listing_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_portfolio_listing';
    }

    public function get_title() {
        return esc_html__('Portfolio Listing', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-gallery-justified';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    public function get_script_depends() {
        return ['elementor_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Portfolio Listing', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'listing_type',
            [
                'label'     => esc_html__('Type', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'grid',
                'options'   => [
                    'grid'      => esc_html__('Grid', 'cosmecos_plugin'),
                    'masonry'   => esc_html__('Masonry', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'columns_number',
            [
                'label'     => esc_html__('Columns Number', 'cosmecos_plugin'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 3,
                'min'       => 2,
                'max'       => 6,
                'condition' => [
                    'listing_type' => 'grid'
                ]
            ]
        );

        $this->add_responsive_control(
            'item_spacing',
            [
                'label' => esc_html__('Space between items', 'cosmecos_plugin'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 60
                    ]
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 30
                ],
                'selectors' => [
                    '{{WRAPPER}} .portfolio-listing-wrapper' => 'margin: calc(-{{SIZE}}{{UNIT}}/2);',
                    '{{WRAPPER}} .portfolio-listing-wrapper .portfolio-item-wrapper' => 'padding: calc({{SIZE}}{{UNIT}}/2);'
                ]
            ]
        );

        $this->add_control(
            'filter',
            [
                'label'     => esc_html__('Category Filter', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('Hide', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Show', 'cosmecos_plugin'),
                'default'   => 'yes',
                'separator' => 'after'
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'portfolio_item',
            [
                'label'         => esc_html__('Choose Portfolio Item', 'cosmecos_plugin'),
                'type'          => Controls_Manager::SELECT2,
                'options'       => cosmecos_get_all_portfolio_list(),
                'label_block'   => true,
                'multiple'      => false
            ]
        );

        $this->add_control(
            'portfolio',
            [
                'label'         => esc_html__('Items', 'cosmecos_plugin'),
                'type'          => Controls_Manager::REPEATER,
                'fields'        => $repeater->get_controls(),
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section();

        // -------------------------------------- //
        // ---------- Filter Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'filter_settings_section',
            [
                'label'     => esc_html__('Filter Settings', 'cosmecos_plugin'),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'filter'    => 'yes'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'filter_typography',
                'label'     => esc_html__('Filter Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .filter-control-wrapper .filter-control-item'
            ]
        );

        $this->start_controls_tabs('filter_tabs');
            // ------ Normal Tab ------ //
            $this->start_controls_tab(
                'tab_filter_normal',
                [
                    'label'     => esc_html__('Normal', 'cosmecos_plugin')
                ]
            );
                $this->add_control(
                    'filter_color_normal',
                    [
                        'label'     => esc_html__('Filter Item Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .filter-control-wrapper .filter-control-item' => 'color: {{VALUE}};'
                        ]
                    ]
                );
                $this->add_control(
                    'filter_marker_normal',
                    [
                        'label'     => esc_html__('Filter Marker Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .filter-control-wrapper .filter-control-item:after' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();

            // ------ Active Tab ------ //
            $this->start_controls_tab(
                'tab_filter_active',
                [
                    'label'     => esc_html__('Active', 'cosmecos_plugin')
                ]
            );
                $this->add_control(
                    'filter_color_hover',
                    [
                        'label'     => esc_html__('Filter Item Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .filter-control-wrapper .filter-control-item:hover, {{WRAPPER}} .filter-control-wrapper .filter-control-item.active' => 'color: {{VALUE}};'
                        ]
                    ]
                );
                $this->add_control(
                    'filter_marker_hover',
                    [
                        'label'     => esc_html__('Filter Marker Color', 'cosmecos_plugin'),
                        'type'      => Controls_Manager::COLOR,
                        'selectors' => [
                            '{{WRAPPER}} .filter-control-wrapper .filter-control-item:hover:after, {{WRAPPER}} .filter-control-wrapper .filter-control-item.active:after' => 'background-color: {{VALUE}};'
                        ]
                    ]
                );
            $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();


        // ------------------------------------ //
        // ---------- Media Settings ---------- //
        // ------------------------------------ //
        $this->start_controls_section(
            'media_settings_section',
            [
                'label' => esc_html__('Media Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'media_icon_color',
            [
                'label'     => esc_html__('Image Overlay Icon Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-item-wrapper .portfolio-item-link:after' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'media_border_color',
            [
                'label'     => esc_html__('Image Overlay Border Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-item-wrapper .portfolio-item-link:before' => 'border-color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'media_background_color',
            [
                'label'     => esc_html__('Image Overlay Background Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-item-wrapper .portfolio-item-link:before' => 'background-color: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings       = $this->get_settings();

        $listing_type   = $settings['listing_type'];
        $columns_number = $settings['columns_number'];
        $filter         = $settings['filter'];
        $portfolios     = $settings['portfolio'];

        if ($listing_type == 'grid') {
            $cols = (int)$columns_number;
            $is_masonry = false;
        } else {
            $cols = 4;
            $is_masonry = true;
        }

        $wrapper_class = 'archive-listing-wrapper portfolio-listing-wrapper isotope-trigger' . ($listing_type == 'grid' && !empty($cols) ? ' portfolio-grid-listing columns-' . esc_attr($cols) : '') . ($listing_type == 'masonry' ? ' portfolio-masonry-listing' : '');

        $i = 1;

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        ?>

        <div class="cosmecos-portfolio-listing-widget<?php echo ($filter == 'yes' ? esc_attr(' isotope-filter') : '') ?>"<?php echo ($filter == 'yes' ? ' data-columns="' . esc_attr($cols) . '" data-spacings="true"' : '') ?>>
            <?php
                if ( $filter == 'yes' ) {
                    $terms = array();
                    foreach ($portfolios as $portfolio) {
                        $post_id = $portfolio['portfolio_item'];
                        $categories = get_the_terms($post_id, 'portfolio-category');
                        $terms = array_merge($terms, $categories);
                    }

                    if ( count( $terms ) > 1 ) {
                        echo "<div class='filter-control-wrapper'>";

                        foreach ( $terms as $term ) {
                            $term_name = $term->name;
                            $filter_vals[$term->slug] = $term_name;
                        }
                        if ( $filter_vals > 1 ){
                            echo "<nav class='nav filter-control-list'>";
                                echo "<div class='dots'>";
                                    echo "<span class='dot filter-control-item all active' data-value='all'>";
                                        echo esc_html__( 'All Photo', 'cosmecos' );
                                    echo "</span>";
                                    foreach ( $filter_vals as $term_slug => $term_name ){
                                        echo "<span class='dot filter-control-item' data-value='" . esc_html( $term_slug ) . "'>";
                                            echo esc_html( $term_name );
                                        echo "</span>";
                                    }
                                echo "</div>";
                            echo "</nav>";
                        }

                        echo "</div>";
                    }
                }
            ?>
            <div class="archive-listing">
                <div class="<?php echo esc_attr($wrapper_class); ?>">
                    <?php

                    echo '<div class="grid-sizer"></div>';

                    foreach ($portfolios as $portfolio) {
                        $post_id = $portfolio['portfolio_item'];

                        $categories = get_the_terms($post_id, 'portfolio-category');
                        $cat_array = array();
                        foreach ( $categories as $category ) {
                            $category_name = $category->slug;
                            $cat_array[] = $category_name;
                        }
                        $cat_classes = ' all ' . implode(' ', $cat_array);

                        $item_class = 'portfolio-item-wrapper item-order-' . esc_attr($i) . esc_attr($cat_classes) . ' elementor-repeater-item-' . esc_attr($portfolio['_id']);

                        if ( $filter == 'yes' && $listing_type == 'grid' ) {
                            $data_sizes = ' data-masonry-width="1" data-masonry-height="1"';
                        } else {
                            if ( $i == 3 || $i == 6 ) {
                                $data_sizes = ' data-masonry-width="2" data-masonry-height="2"';
                            } else {
                                $data_sizes = ' data-masonry-width="1" data-masonry-height="1"';
                            }
                        }
                        ?>

                        <div <?php post_class(esc_attr($item_class)); ?><?php echo esc_attr($data_sizes); ?>>
                            <div class="portfolio-item">
                                <a class="portfolio-item-link" href="<?php echo esc_url(get_permalink($post_id)); ?>">
                                    <?php echo cosmecos_portfolio_grid_media_output($post_id, $cols, $is_masonry, $i); ?>
                                </a>
                            </div>
                        </div>
                        <?php

                        if ($i < 10) {
                            $i++;
                        } else {
                            $i = 1;
                        }
                    }
                    ?>
                </div>
            </div>
        </div>
        <?php
    }

    protected function content_template() {}

    public function render_plain_content() {}
}