<?php
/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\REPEATER;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Price_Item_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_price_item';
    }

    public function get_title() {
        return esc_html__('Price Item', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-price-table';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Price Item', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'title',
            [
                'label'     => esc_html__('Title', 'cosmecos_plugin'),
                'type'      => Controls_Manager::TEXT,
                'default'   => ''
            ]
        );

        $this->add_control(
            'block_type',
            [
                'label'     => esc_html__('Price Item Type', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'standard',
                'options'   => [
                    'standard'  => esc_html__('Standard', 'cosmecos_plugin'),
                    'wide'      => esc_html__('Wide', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'active_block_status',
            [
                'label'     => esc_html__('Highlight this block?', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('No', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Yes', 'cosmecos_plugin'),
                'default'   => 'no'
            ]
        );

        $this->add_control(
            'currency',
            [
                'label'         => esc_html__('Currency', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => '$',
                'separator'     => 'before'
            ]
        );

        $this->add_control(
            'currency_position',
            [
                'label'     => esc_html__('Currency Position', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'before',
                'options'   => [
                    'before'    => esc_html__('Before Price', 'cosmecos_plugin'),
                    'after'     => esc_html__('After Price', 'cosmecos_plugin')
                ]
            ]
        );

        $this->add_control(
            'price',
            [
                'label'     => esc_html__('Price', 'cosmecos_plugin'),
                'type'      => Controls_Manager::TEXT,
                'default'   => ''
            ]
        );

        $this->add_control(
            'period',
            [
                'label'         => esc_html__('Period', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__('month', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'custom_fields',
            [
                'label'         => esc_html__('Custom Fields', 'cosmecos_plugin'),
                'type'          => Controls_Manager::REPEATER,
                'default'       => [],
                'fields'        => [
                    [
                        'name'          => 'text',
                        'label'         => esc_html__( 'Text', 'cosmecos_plugin' ),
                        'type'          => Controls_Manager::TEXT,
                        'label_block'   => true,
                        'default'       => '',
                        'placeholder'   => esc_html__( 'Enter Text', 'cosmecos_plugin' ),
                    ]
                ],
                'title_field'   => '{{{text}}}',
                'separator'     => 'before'
            ]
        );

        $this->add_control(
            'price_button_text',
            [
                'label'         => esc_html__('Button Text', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'default'       => esc_html__('Get Started', 'cosmecos_plugin'),
                'placeholder'   => esc_html__('Button Text', 'cosmecos_plugin'),
                'separator'     => 'before'
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label'         => esc_html__('Link', 'cosmecos_plugin'),
                'type'          => Controls_Manager::URL,
                'placeholder'   => esc_url('http://your-link.com'),
                'default'       => [
                    'url'   => '#',
                ]
            ]
        );

        $this->end_controls_section();

        // ----------------------------------------- //
        // ---------- Price Item Settings ---------- //
        // ----------------------------------------- //
        $this->start_controls_section(
            'section_settings',
            [
                'label' => esc_html__('Price Item Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'      => 'item_bg',
                'label'     => esc_html__( 'Background', 'cosmecos_plugin' ),
                'types'     => [ 'classic' ],
                'selector'  => '{{WRAPPER}} .price-item'
            ]
        );

        $this->add_control(
            'frame_status',
            [
                'label'     => esc_html__('Add frame', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SWITCHER,
                'label_off' => esc_html__('No', 'cosmecos_plugin'),
                'label_on'  => esc_html__('Yes', 'cosmecos_plugin'),
                'default'   => 'yes',
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'              => 'item_bd',
                'label'             => esc_html__( 'Price Item Frame', 'cosmecos_plugin' ),
                'selector'          => '{{WRAPPER}} .price-item:before',
                'fields_options' => [
                    'border' => [
                        'default' => 'solid',
                    ],
                    'width' => [
                        'default' => [
                            'top'       => '1',
                            'right'     => '1',
                            'bottom'    => '1',
                            'left'      => '1',
                            'isLinked'  => true
                        ],
                    ],
                    'color' => [
                        'default' => '#232323',
                    ],
                ],
                'condition'         => [
                    'frame_status' => 'yes'
                ]
            ]
        );

        $this->end_controls_section();

        // -------------------------------------- //
        // ---------- Content Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'section_content_settings',
            [
                'label' => esc_html__('Content Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'title_margin',
            [
                'label'     => esc_html__('Space After Title', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 200
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-item-title' => 'margin-bottom: {{SIZE}}{{UNIT}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Title Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .price-item-title'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Title Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-item-title' => 'color: {{VALUE}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'price_margin',
            [
                'label'     => esc_html__('Space After Price', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 200
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-wrapper' => 'margin-bottom: {{SIZE}}{{UNIT}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'price_typography',
                'label'     => esc_html__('Price Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .price, {{WRAPPER}} .currency'
            ]
        );

        $this->add_control(
            'price_color',
            [
                'label'     => esc_html__('Price Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-item .price-wrapper' => 'color: {{VALUE}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'period_typography',
                'label'     => esc_html__('Period Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .period'
            ]
        );

        $this->add_control(
            'period_color',
            [
                'label'     => esc_html__('Period Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .period' => 'color: {{VALUE}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'fields_margin',
            [
                'label'     => esc_html__('Space Between Custom Fields', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 200
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-item-custom-field' => 'margin-bottom: {{SIZE}}{{UNIT}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'fields_typography',
                'label'     => esc_html__('Custom Fields Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .price-item-custom-field'
            ]
        );

        $this->add_control(
            'fields_color',
            [
                'label'     => esc_html__('Custom Fields Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-item-custom-field' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section();

        // ------------------------------------- //
        // ---------- Button Settings ---------- //
        // ------------------------------------- //
        $this->start_controls_section(
            'section_button_settings',
            [
                'label' => esc_html__('Button Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'button_margin',
            [
                'label'     => esc_html__('Space Before Button', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 200
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .price-item-button-container' => 'margin-top: {{SIZE}}{{UNIT}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'button_typography',
                'label'     => esc_html__('Button Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .price-item-button-container .cosmecos-button'
            ]
        );

        $this->add_control(
            'button_color',
            [
                'label'     => esc_html__('Button Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-item-button-container .cosmecos-button' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'button_bd',
            [
                'label'     => esc_html__('Button Border Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-item-button-container .cosmecos-button' => 'border-color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'button_bg',
            [
                'label'     => esc_html__('Button Background Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .price-item-button-container .cosmecos-button:before' => 'background-color: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings               = $this->get_settings();

        $block_type             = $settings['block_type'];
        $title                  = $settings['title'];
        $active_block_status    = $settings['active_block_status'];
        $currency               = $settings['currency'];
        $currency_position      = $settings['currency_position'];
        $price                  = $settings['price'];
        $period                 = $settings['period'];
        $custom_fields          = $settings['custom_fields'];
        $price_button_text      = $settings['price_button_text'];
        $button_link            = $settings['button_link'];
        $frame_status           = $settings['frame_status'];

        if ($button_link['url'] !== '') {
            $button_url         = $button_link['url'];
        } else {
            $button_url         = '#';
        }

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        ?>

        <div class="cosmecos-price-item-widget<?php echo ($frame_status == 'yes' ? ' with_frame' : ''); ?>">
            <div class="price-item<?php echo ($active_block_status == 'yes' ? ' active' : '') . ' price-item-type-' . esc_attr($block_type); ?>">
                <?php
                if ( !empty($price) && $block_type == 'wide') {
                    ?>
                    <div class="price-item-container price-item-currency-position-<?php echo esc_attr($currency_position); ?>">
                        <div class="price-wrapper">
                            <?php
                            if ($currency !== '') {
                                if ($currency_position == 'before') {
                                    echo '<span class="currency">' . esc_html($currency) . '</span>';
                                }
                            }

                            echo '<span class="price">' . esc_html($price) . '</span>';

                            if ($currency !== '') {
                                if ($currency_position == 'after') {
                                    echo '<span class="currency">' . esc_html($currency) . '</span>';
                                }
                            }
                            ?>
                        </div>

                        <?php
                        if ($period !== '') {
                            echo '<div class="price-item-period">' . esc_html($period) . '</div>';
                        }
                        ?>
                    </div>
                    <?php
                }
                ?>

                <div class="price-item-inner">
                    <?php
                    if ($title !== '') {
                        echo '<div class="price-item-title">' . esc_html($title) . '</div>';
                    }

                    if ( !empty($price) && $block_type == 'standard') {
                        ?>
                        <div class="price-item-container price-item-currency-position-<?php echo esc_attr($currency_position); ?>">
                            <div class="price-wrapper">
                                <?php
                                if ($currency !== '') {
                                    if ($currency_position == 'before') {
                                        echo '<span class="currency">' . esc_html($currency) . '</span>';
                                    }
                                }

                                echo '<span class="price">' . esc_html($price) . '</span>';

                                if ($currency !== '') {
                                    if ($currency_position == 'after') {
                                        echo '<span class="currency">' . esc_html($currency) . '</span>';
                                    }
                                }
                                ?>
                            </div>

                            <?php
                            if ($period !== '') {
                                echo '<div class="price-item-period">' . esc_html($period) . '</div>';
                            }
                            ?>
                        </div>
                        <?php
                    }

                    if (!empty($custom_fields)) {
                        ?>
                        <div class="price-item-custom-fields">
                            <?php
                            foreach ($custom_fields as $field) {
                                $field_status_class = '';
                                ?>

                                <div class="price-item-custom-field <?php echo esc_attr($field_status_class); ?>"><?php echo esc_html($field['text']); ?></div>
                                <?php
                            }
                            ?>
                        </div>
                        <?php
                    }
                    ?>

                    <div class="price-item-button-container">
                        <a class="cosmecos-button" href="<?php echo esc_url($button_url); ?>" <?php echo (($button_link['is_external'] == true) ? 'target="_blank"' : ''); echo (($button_link['nofollow'] == 'on') ? 'rel="nofollow"' : ''); ?>><?php echo esc_html($price_button_text); ?></a>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    protected function content_template() {}

    public function render_plain_content() {}
}