<?php

/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Product_Category_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_product_category';
    }

    public function get_title() {
        return esc_html__('Product Category', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-product-categories';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    public function get_script_depends() {
        return ['elementor_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_display_product_category',
            [
                'label' => esc_html__('Product Category', 'cosmecos_plugin')
            ]
        );

        $cat_args = array(
            'orderby'    => 'name',
            'order'      => 'asc',
            'hide_empty' => false,
        );
        $product_categories = get_terms( 'product_cat', $cat_args );
        $category_arr       = [ '' => esc_attr__('None', 'cosmecos_plugin') ];
        if( !empty($product_categories) ){
            foreach ($product_categories as $key => $category) {
                $category_arr[$category->term_taxonomy_id] = $category->name;
            }
        }
        $this->add_control(
            'category',
            [
                'label'         => esc_html__('Select Category', 'cosmecos_plugin'),
                'type'          => Controls_Manager::SELECT,
                'options'       => $category_arr,
                'default'       => ''
            ]
        );

        $this->add_control(
            'image',
            [
                'label'     => esc_html__('Image', 'cosmecos_plugin'),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [
                    'url'       => Utils::get_placeholder_image_src(),
                ]
            ]
        );

        $this->end_controls_section();

        // ------------------------------------ //
        // ---------- Style Settings ---------- //
        // ------------------------------------ //
        $this->start_controls_section(
            'section_item_settings',
            [
                'label' => esc_html__('Product Category Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_responsive_control(
            'block_height',
            [
                'label'     => esc_html__('Block height', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px'        => [
                        'min'       => 0,
                        'max'       => 1000
                    ]
                ],
                'default'   => [
                    'unit'      => 'px',
                    'size'      => 592
                ],
                'selectors' => [
                    '{{WRAPPER}} .product-category-widget' => 'height: {{SIZE}}{{UNIT}};'
                ]
            ]
        );

        $this->add_control(
            'border_color',
            [
                'label'     => esc_html__('Border Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .product-category-widget:before' => 'border-color: {{VALUE}};'
                ]
            ]
        );

        $this->add_control(
            'title_bg_color',
            [
                'label'     => esc_html__('Title Background Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .product-category-widget .product-category-header, {{WRAPPER}} .product-category-widget .product-category-title' => 'background-color: {{VALUE}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'title_typography',
                'label'     => esc_html__('Title Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .product-category-widget .product-category-title'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Title Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .product-category-widget .product-category-title' => 'color: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings           = $this->get_settings();
        $image              = $settings['image'];
        $category           = $settings['category'];

        $image_src          = $image['url'];
        $image_meta         = cosmecos_get_attachment_meta($image['id']);
        $image_alt_text     = $image_meta['alt'];

        $product_category   = get_term( $category );
        $category_link      = get_term_link($product_category);

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        if ( !empty($category) ) {
            echo '<a href="' . esc_url($category_link) . '" class="product-category-widget">';
                if (!empty($image_src)) {
                    echo '<img class="product-category-image" src="' . esc_url($image_src) . '" alt="' . esc_attr($image_alt_text) . '" />';
                }
                echo '<span class="product-category-header">';
                    echo '<span class="product-category-title">' . esc_html($product_category->name) . '</span>';
                echo '</span>';
            echo '</a>';
        }
    }

    protected function content_template() {}

    public function render_plain_content() {}
}