<?php

/*
 * Created by Artureanec
*/

namespace Cosmecos\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cosmecos_Special_Text_Widget extends Widget_Base {

    public function get_name() {
        return 'cosmecos_special_text';
    }

    public function get_title() {
        return esc_html__('Special Text', 'cosmecos_plugin');
    }

    public function get_icon() {
        return 'eicon-t-letter';
    }

    public function get_categories() {
        return ['cosmecos_widgets'];
    }

    protected function _register_controls() {

        // ----------------------------- //
        // ---------- Content ---------- //
        // ----------------------------- //
        $this->start_controls_section(
            'section_special_text',
            [
                'label' => esc_html__('Special Text', 'cosmecos_plugin')
            ]
        );

        $this->add_control(
            'text',
            [
                'label'         => esc_html__('Text', 'cosmecos_plugin'),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__('Enter Text', 'cosmecos_plugin')
            ]
        );

        $this->add_responsive_control(
            'text_align',
            [
                'label'     => esc_html__('Alignment', 'cosmecos_plugin'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'      => [
                        'title'     => esc_html__('Left', 'cosmecos_plugin'),
                        'icon'      => 'fa fa-align-left',
                    ],
                    'center'    => [
                        'title'     => esc_html__('Center', 'cosmecos_plugin'),
                        'icon'      => 'fa fa-align-center',
                    ],
                    'right'     => [
                        'title'     => esc_html__('Right', 'cosmecos_plugin'),
                        'icon'      => 'fa fa-align-right',
                    ]
                ],
                'default'   => 'left',
                'selectors' => [
                    '{{WRAPPER}} .special-text' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        // -------------------------------------- //
        // ---------- Heading Settings ---------- //
        // -------------------------------------- //
        $this->start_controls_section(
            'section_text_settings',
            [
                'label' => esc_html__('Text Settings', 'cosmecos_plugin'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'text_typography',
                'label'     => esc_html__('Heading Typography', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .special-text'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Text Color', 'cosmecos_plugin'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .special-text' => 'color: {{VALUE}};'
                ],
                'separator' => 'after'
            ]
        );

        $this->add_control(
            'text_opacity',
            [
                'label'     => esc_html__('Opacity', 'cosmecos_plugin'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    '%'         => [
                        'min'       => 0,
                        'max'       => 1,
                        'step'      => .01
                    ]
                ],
                'default'   => [
                    'unit'      => '%',
                    'size'      => 0.2,
                ],
                'selectors' => [
                    '{{WRAPPER}} .special-text' => 'opacity: {{SIZE}};'
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(),
            [
                'name'      => 'text_shadow',
                'label'     => esc_html__('Text Shadow', 'cosmecos_plugin'),
                'selector'  => '{{WRAPPER}} .special-text'
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings   = $this->get_settings();
        $text    = $settings['text'];

        // ------------------------------------ //
        // ---------- Widget Content ---------- //
        // ------------------------------------ //
        if ( !empty($text) ) {
            echo '<div class="special-text">';
                echo esc_html($text);
            echo '</div>';
        }
    }

    protected function content_template() {}

    public function render_plain_content() {}
}
