<?php
/*
 * Created by Artureanec
*/

if (!class_exists('cosmecos_contacts_widget'))
{
    class cosmecos_contacts_widget extends WP_Widget
    {
        public function __construct()
        {
            parent::__construct(
                'cosmecos_contacts_widget',
                'Contacts Widget (Cosmecos Theme)',
                array(
                    'description' => esc_html__('Contacts Widget by Cosmecos Theme', 'cosmecos_plugin'),
                    'mime_type'   => 'image'
                )
            );
        }

        public function update($new_instance, $old_instance)
        {
            $instance = $old_instance;

            $instance['title']      = esc_attr($new_instance['title']);
            $instance['logo']       = strip_tags($new_instance['logo']);
            $instance['logo_id']    = esc_attr($new_instance['logo_id']);
            $instance['retina']     = esc_attr($new_instance['retina']);
            $instance['address']    = esc_attr($new_instance['address']);
            $instance['phone']      = esc_attr($new_instance['phone']);
            $instance['email']      = esc_attr($new_instance['email']);
            $instance['social']     = esc_attr($new_instance['social']);
            $instance['text']       = esc_attr($new_instance['text']);

            return $instance;
        }

        public function form($instance)
        {
            $default_values = array(
                'title'     => '',
                'logo'      => '',
                'logo_id'   => '',
                'retina'    => false,
                'address'   => '',
                'phone'     => '',
                'email'     => '',
                'social'    => 'disabled',
                'text'      => ''
            );

            $instance = wp_parse_args((array)$instance, $default_values);
            $retina     = isset( $instance['retina'] ) ? (bool) $instance['retina'] : false;
            ?>

            <div class="cosmecos_widget">
                <div class="media-widget-control">
                    <p>
                        <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                            <?php echo esc_html__('Title', 'cosmecos_plugin'); ?>:
                        </label>
                        <input class="widefat"
                               type="text"
                               id="<?php echo esc_attr($this->get_field_id('title')); ?>"
                               name="<?php echo esc_attr($this->get_field_name('title')); ?>"
                               value="<?php echo esc_html($instance['title']); ?>"
                        />
                    </p>

                    <p>
                        <label for="<?php echo $this->get_field_id( 'logo' ); ?>"><?php echo esc_html__( 'Logo:', 'cosmecos_plugin' ); ?></label>
                    </p>

                    <div class="media-widget-preview media_image">
                        <?php
                        $logo_id = !empty($instance['logo']) ? attachment_url_to_postid( $instance['logo'] ) : '';

                        if ( !empty($logo_id) ) {
                            if ( wp_get_attachment_image_url($logo_id, 'medium') ) {
                                $logo_url = wp_get_attachment_image_url($logo_id, 'medium');
                            } else {
                                $logo_url = wp_get_attachment_image_url($logo_id, 'full');
                            }
                        } else {
                            $logo_url = get_template_directory_uri() . '/img/null.png';
                        }
                        echo '<img class="attachment-thumb ' . $this->get_field_id( 'logo' ) . '_img' . (empty($instance['logo']) ? ' hidden' : '') . '" src="' . esc_url($logo_url) . '" />';
                        ?>
                        <div class="attachment-media-view">
                            <button type="button" id="<?php echo $this->get_field_id( 'logo' ) ?>" class="button select-media button-add-media not-selected js_custom_upload_media<?php echo empty($instance['logo']) ? ' empty' : ' hidden'; ?>"><?php echo esc_html__('Add Image', 'cosmecos_plugin') ?></button>
                        </div>
                        <input hidden type="text" class="widefat <?php echo $this->get_field_id( 'logo' ) ?>_url" name="<?php echo esc_attr( $this->get_field_name( 'logo' ) ); ?>" value="<?php echo !empty($instance['logo']) ? $instance['logo'] : ''; ?>" />
                        <input hidden type="text" class="widefat2 <?php echo $this->get_field_id( 'logo' ) ?>_id" name="<?php echo esc_attr( $this->get_field_name( 'logo_id' ) ); ?>" value="<?php echo !empty($instance['logo_id']) ? $instance['logo_id'] : ''; ?>" />
                    </div>

                    <p class="media-widget-buttons">
                        <button id="<?php echo $this->get_field_id( 'logo' ).'_remove' ?>" type="button" class="button js_custom_remove_media<?php echo (empty($instance['logo']) ? ' hidden' : ''); ?>"><?php echo esc_html__('Replace Image', 'cosmecos_plugin') ?></button>
                    </p>

                    <p>
                        <label for="<?php echo $this->get_field_id( 'retina' ); ?>">
                            <input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'retina' ); ?>" name="<?php echo $this->get_field_name( 'retina' ); ?>"<?php checked( $retina ); ?> />
                            <?php esc_html_e( 'Logo Retina', 'cosmecos_plugin' ); ?>
                        </label>
                    </p>

                    <p>
                        <label for="<?php echo esc_attr($this->get_field_id('address')); ?>">
                            <?php echo esc_html__('Address', 'cosmecos_plugin'); ?>:
                        </label>
                        <textarea class="widefat"
                               id="<?php echo esc_attr($this->get_field_id('address')); ?>"
                               name="<?php echo esc_attr($this->get_field_name('address')); ?>"
                        ><?php echo esc_attr($instance['address']); ?></textarea>
                    </p>

                    <p>
                        <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>">
                            <?php echo esc_html__('Phone Number', 'cosmecos_plugin'); ?>:
                        </label>
                        <input class="widefat"
                               type="text"
                               id="<?php echo esc_attr($this->get_field_id('phone')); ?>"
                               name="<?php echo esc_attr($this->get_field_name('phone')); ?>"
                               value="<?php echo esc_html($instance['phone']); ?>"
                        />
                    </p>

                    <p>
                        <label for="<?php echo esc_attr($this->get_field_id('email')); ?>">
                            <?php echo esc_html__('Email', 'cosmecos_plugin'); ?>:
                        </label>
                        <input class="widefat"
                               type="text"
                               id="<?php echo esc_attr($this->get_field_id('email')); ?>"
                               name="<?php echo esc_attr($this->get_field_name('email')); ?>"
                               value="<?php echo esc_html($instance['email']); ?>"
                        />
                    </p>

                    <p>
                        <label for="<?php echo esc_attr($this->get_field_id('social')); ?>">
                            <?php echo esc_html__('Social Buttons', 'cosmecos_plugin'); ?>:
                        </label>
                        <select name="<?php echo esc_attr($this->get_field_name('social')); ?>"
                                id="<?php echo esc_attr($this->get_field_id('social')); ?>">
                            <option value="disabled" <?php selected($instance['social'], 'disabled'); ?>><?php echo esc_html__('Disabled', 'cosmecos_plugin'); ?></option>
                            <option value="enabled" <?php selected($instance['social'], 'enabled'); ?>><?php echo esc_html__('Enabled', 'cosmecos_plugin'); ?></option>
                        </select>
                    </p>

                    <p>
                        <label for="<?php echo esc_attr($this->get_field_id('text')); ?>">
                            <?php echo esc_html__('Description', 'cosmecos_plugin'); ?>:
                        </label>
                        <textarea class="widefat"
                                  id="<?php echo esc_attr($this->get_field_id('text')); ?>"
                                  name="<?php echo esc_attr($this->get_field_name('text')); ?>"
                        ><?php echo esc_attr($instance['text']); ?></textarea>
                    </p>

                </div>
            </div>
            <?php
        }

        public function widget($args, $instance) {
            extract($args);

            echo $before_widget;
            if ($instance['title']) {
                echo $before_title;
                echo apply_filters('widget_title', $instance['title']);
                echo $after_title;
            }

            if ( !empty($instance['logo']) && !empty($instance['logo_id']) ) {
                $demo_url = 'https://demo.artureanec.com/themes/cosmecos-new';
                $current_url = get_home_url();
                if ( strpos($instance['logo'], $demo_url) === false ) {
                    $url = $instance['logo'];
                } else {
                    $url = str_replace($demo_url, $current_url, $instance['logo']);
                }
                $logo_id = $instance['logo_id'];
                $logo_meta = wp_get_attachment_metadata( $logo_id );
                if ( $instance['retina'] == true ) {
                    $logo_width = (isset($logo_meta['width']) ? floor($logo_meta['width'] / 2 ) : 0);
                    $logo_height = (isset($logo_meta['height']) ? floor( $logo_meta['height'] / 2 ) : 0);
                } else {
                    $logo_width = (isset($logo_meta['width']) ? $logo_meta['width'] : 0);
                    $logo_height = (isset($logo_meta['height']) ? $logo_meta['height'] : 0);
                }
                echo '<div class="cosmecos-contacts-widget-logo logo' . ($instance['retina'] == true ? ' retina-logo' : '') . '">';
                    echo '<a href="' . esc_url(home_url('/')) . '" class="logo-link">';
                        echo '<img width="' . esc_attr($logo_width) . '" height="' . esc_attr($logo_height) . '" src="'.esc_url($url).'" alt="' . esc_attr(get_post_meta(attachment_url_to_postid($url), '_wp_attachment_image_alt', TRUE)) . '" />';
                    echo '</a>';
                echo '</div>';
            }

            if ($instance['text'] !== '') {
                echo '
                    <div class="cosmecos-contacts-widget-description">
                        <p>
                            ' . esc_html($instance['text']) . '
                        </p>
                    </div>
                ';
            }

            if ($instance['address'] !== '') {
                echo '<div class="cosmecos-contacts-widget-field cosmecos-contacts-widget-address">';
                    echo esc_html($instance['address']);
                echo '</div>';
            }

            if ($instance['email'] !== '') {
                echo '
                    <div class="cosmecos-contacts-widget-field cosmecos-contacts-widget-email">
                        <a href="mailto:' . esc_attr($instance['email']) . '">
                            ' . esc_html($instance['email']) . '
                        </a>
                    </div>
                ';
            }

            if ($instance['phone'] !== '') {
                $phone = '+' . preg_replace('~\D+~','', $instance['phone']);
                echo '
                    <div class="cosmecos-contacts-widget-field cosmecos-contacts-widget-phone">
                        <a href="tel:' . esc_attr($phone) . '">
                            ' . esc_html($instance['phone']) . '
                        </a>
                    </div>
                ';
            }

            if (isset($instance['social']) && $instance['social'] == 'enabled') {
                echo cosmecos_socials_output('widget-socials wrapper-socials');
            }

            echo $after_widget;
        }
    }
}
