<?php
# One Click Demo Content Import
if (!function_exists('cosmecos_ocdi_import_files')) {
    function cosmecos_ocdi_import_files() {
        return array(
            array(
                'import_file_name'              => 'Cosmecos',
                'categories'                    => array('With Images'),
                'import_file_url'               => trailingslashit(get_template_directory_uri()) . 'core/import/import.xml',
                'import_widget_file_url'        => trailingslashit(get_template_directory_uri()) . 'core/import/widgets.xml',
                'import_customizer_file_url'    => trailingslashit(get_template_directory_uri()) . 'core/import/customizer.xml',
                'import_preview_image_url'      => trailingslashit(get_template_directory_uri()) . 'screenshot.png',
                'preview_url'                   => 'https://demo.artureanec.com/themes/cosmecos-new',
            ),
        );
    }
}
add_filter( 'pt-ocdi/import_files', 'cosmecos_ocdi_import_files' );

# Remove Branding Message
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

# Disable Regenerate for Thumbs
//add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' ); // This will greatly improve the time needed to import the content (images), but only the original sized images will be imported.

if (!function_exists('cosmecos_after_activation')) {
    function cosmecos_after_activation() {
        function cosmecos_after_switch_theme_message() {
            echo '<div class="updated notice is-dismissible"><p>' . esc_html__('After activating all the recommended plugins, you can import all demo content in one-touch. Appearance > Import Demo Data.', 'cosmecos') . '</p></div>';
        }
        add_action('admin_notices', 'cosmecos_after_switch_theme_message');
    }
}
add_action('after_switch_theme', 'cosmecos_after_activation', 10 , 2);

# Remove all posts, pages and products before content import
if ( !function_exists('cosmecos_ocdi_before_content_import') ) {
    function cosmecos_ocdi_before_content_import() {
        $allposts= get_posts( array(
            'post_type'     => array('post', 'page', 'products', 'attachment', ''),
            'numberposts'   => -1
        ) );
        foreach ($allposts as $eachpost) {
            wp_delete_post( $eachpost->ID, true );
        }
    }
}
add_action( 'pt-ocdi/before_content_import', 'cosmecos_ocdi_before_content_import' );

# Clear sidebars before the widgets get imported
if ( !function_exists('cosmecos_ocdi_before_widgets_import') ) {
    function cosmecos_ocdi_before_widgets_import() {
        update_option( 'sidebars_widgets', array() );
    }
}
add_action( 'pt-ocdi/before_widgets_import', 'cosmecos_ocdi_before_widgets_import' );


if (!function_exists('cosmecos_ocdi_after_import_setup')) {
    function cosmecos_ocdi_after_import_setup() {
        // Assign menus to their locations.
        $main_menu              = get_term_by('name', 'Main Menu', 'nav_menu');
        $top_bar_user_menu      = get_term_by('name', 'Top Bar User Menu', 'nav_menu');
        $footer_menu            = get_term_by('name', 'Footer Menu', 'nav_menu');
        $footer_additional_menu = get_term_by('name', 'Footer Additional Menu', 'nav_menu');

        set_theme_mod('nav_menu_locations', array(
            'main'              => $main_menu->term_id,
            'top_bar_user_menu' => $top_bar_user_menu->term_id,
            'footer_menu'       => $footer_menu->term_id,
            'footer_add_menu'   => $footer_additional_menu->term_id,
        ));

        // Assign front page and posts page (blog page).
        $front_page_id = get_page_by_title('Cosmetic Shop');
        # $blog_page_id  = get_page_by_title( 'Blog' );
        update_option('show_on_front', 'page');
        update_option('page_on_front', $front_page_id->ID);
        // update_option( 'page_for_posts', $blog_page_id->ID );

        // Set WooCommerce options
        if ( class_exists('WooCommerce') ) {
            if (!wc_update_product_lookup_tables_is_running()) {
                wc_update_product_lookup_tables();
            }
            $args = array(
                'post_type'     => 'product',
                'post_status'   => 'publish',
                'orderby'       => 'date',
                'order'         => 'ASC'
            );
            $loop = new WP_Query($args);
            while ($loop->have_posts()) {
                $loop->the_post();
                global $product;
                wc_delete_product_transients($product->get_id());
            }

            $shop_page_id       = get_page_by_title('Shop Catalog');
            $cart_page_id       = get_page_by_title('Shop Cart');
            $checkout_page_id   = get_page_by_title('Shop Checkout');
            $account_page_id    = get_page_by_title('Shop My Account');
            update_option( 'woocommerce_shop_page_id', $shop_page_id->ID );
            update_option( 'woocommerce_cart_page_id', $cart_page_id->ID );
            update_option( 'woocommerce_checkout_page_id', $checkout_page_id->ID );
            update_option( 'woocommerce_myaccount_page_id', $account_page_id->ID );
            update_option( 'permalink_structure', '/%postname%/' );

            // Set wishlist options
            if ( function_exists( 'yith_plugin_registration_hook' ) ) {
                $wishlist_page_id   = get_page_by_title('Shop Wishlist');
                update_option( 'yith_wcwl_wishlist_page_id', $wishlist_page_id->ID );
            }

            // Set Brands options
            if ( is_plugin_active('perfect-woocommerce-brands/perfect-woocommerce-brands.php') ) {
                $brands_page_id = get_page_by_title('Brands A-Z');
                update_option( 'wc_pwb_admin_tab_brands_page_id', $brands_page_id->ID );

                update_option( 'wc_pwb_admin_tab_brand_logo_size', 'thumbnail' );
                update_option( 'wc_pwb_admin_tab_brand_desc', 'no' );
                update_option( 'wc_pwb_admin_tab_brand_banner', 'no' );
                update_option( 'wc_pwb_admin_tab_brands_in_loop', 'no' );
                update_option( 'wc_pwb_admin_tab_brand_single_product_tab', 'no' );
                update_option( 'wc_pwb_admin_tab_brands_in_single', 'no' );
                update_option( 'wc_pwb_admin_tab_brand_single_position', 'meta' );
            }
        }

        // Set Elementor options
        if ( did_action('elementor/loaded') ) {
            update_option('elementor_disable_color_schemes', 'yes');
            update_option('elementor_disable_typography_schemes', 'yes');

            $kit = \Elementor\Plugin::$instance->kits_manager->get_active_kit_for_frontend();
            $kit->update_settings(
                [
                    'container_width' => [
                        'unit'  => 'px',
                        'size'  => 1170,
                        'sizes' => []
                    ],
                ]
            );
            $kit->update_settings(
                [
                    'space_between_widgets' => [
                        'unit'  => 'px',
                        'size'  => 30,
                        'sizes' => []
                    ],
                ]
            );
            $kit->update_settings(
                [
                    'viewport_lg' => 995,
                ]
            );
            $kit->update_settings(
                [
                    'system_colors'         => [
                        0   => [
                            '_id'   => 'primary',
                            'title' => esc_html__('Primary', 'cosmecos'),
                            'color' => '#969696'
                        ],
                        1   => [
                            '_id'   => 'secondary',
                            'title' => esc_html__('Secondary', 'cosmecos'),
                            'color' => '#232323'
                        ],
                        2   => [
                            '_id'   => 'text',
                            'title' => esc_html__('Text', 'cosmecos'),
                            'color' => '#616161'
                        ],
                        3   => [
                            '_id'   => 'accent',
                            'title' => esc_html__('Accent', 'cosmecos'),
                            'color' => '#eaaa85'
                        ]
                    ]
                ]
            );
        }

        // Import forms
        if ( function_exists('wpforms') ) {
            $title = esc_html__('Send Message', 'cosmecos');
            $form_id = wpforms()->form->add($title);
            $form_id = wpforms()->form->update(
                $form_id,
                array(
                    'id'        => 4354,
                    'field_id'  => 6,
                    'fields'    => array(
                        '1'                         => array(
                            'id'                        => '1',
                            'type'                      => 'text',
                            'label'                     => esc_html__('Full name', 'cosmecos'),
                            'description'               => '',
                            'required'                  => '1',
                            'size'                      => 'large',
                            'placeholder'               => esc_attr__('Full name *', 'cosmecos'),
                            'label_hide'                => '1',
                            'limit_count'               => '1',
                            'limit_mode'                => 'characters',
                            'default_value'             => '',
                            'css'                       => 'wpforms-one-half wpforms-first',
                            'input_mask'                => '',
                        ),
                        '2'                         => array(
                            'id'                        => '2',
                            'type'                      => 'email',
                            'label'                     => esc_html__('Email', 'cosmecos'),
                            'description'               => '',
                            'required'                  => '1',
                            'size'                      => 'large',
                            'placeholder'               => esc_attr__('Email *', 'cosmecos'),
                            'confirmation_placeholder'  => '',
                            'label_hide'                => '1',
                            'default_value'             => '',
                            'css'                       => 'wpforms-one-half',
                            'filter_type'               => '',
                            'allowlist'                 => '',
                            'denylist'                  => '',
                        ),
                        '4'                         => array(
                            'id'                        => '4',
                            'type'                      => 'text',
                            'label'                     => esc_html__('Subject', 'cosmecos'),
                            'description'               => '',
                            'size'                      => 'large',
                            'placeholder'               => esc_attr__('Subject', 'cosmecos'),
                            'label_hide'                => '1',
                            'limit_count'               => '1',
                            'limit_mode'                => 'characters',
                            'default_value'             => '',
                            'css'                       => '',
                            'input_mask'                => '',
                        ),
                        '5'                         => array(
                            'id'                        => '5',
                            'type'                      => 'textarea',
                            'label'                     => esc_html__('Message', 'cosmecos'),
                            'description'               => '',
                            'size'                      => 'medium',
                            'placeholder'               => esc_attr__('Message', 'cosmecos'),
                            'label_hide'                => '1',
                            'limit_count'               => '1',
                            'limit_mode'                => 'characters',
                            'default_value'             => '',
                            'css'                       => '',
                        ),
                    ),
                    'settings' => array(
                        'form_title'                => $title,
                        'form_desc'                 => esc_html__('Your email address will not be published. Required fields are marked *', 'cosmecos'),
                        'form_class'                => '',
                        'submit_text'               => esc_html__('Send', 'cosmecos'),
                        'submit_text_processing'    => esc_html__('Sending...', 'cosmecos'),
                        'submit_class'              => '',
                        'antispam'                  => '1',
                        'notification_enable'       => '1',
                        'notifications'             => array(
                            '1'                         => array(
                                'email'                     => '{admin_email}',
                                'subject'                   => __('New Blank Form Entry', 'cosmecos'),
                                'sender_name'               => 'Cosmecos',
                                'sender_address'            => '{admin_email}',
                                'replyto'                   => '',
                                'message'                   => '{all_fields}',
                            ),
                        ),
                        'confirmations'             => array(
                            '1'                         => array(
                                'type'                      => 'message',
                                'message'                   => '<p>' . esc_html__('Thanks for contacting us! We will be in touch with you shortly.', 'cosmecos') . '</p>',
                                'message_scroll'            => '1',
                                'page'                      => '31',
                                'redirect'                  => '',
                            ),
                        ),
                    ),
                    'meta'                      => array(
                        'template'                  => 'blank',
                    ),
                )
            );
            wp_update_post(
                array(
                    'ID'         => $form_id,
                    'post_title' => $title,
                )
            );
        }

    }
}
add_action( 'pt-ocdi/after_import', 'cosmecos_ocdi_after_import_setup' );